//////////////////////////////////////////////////////////////////////////
// Copyright 2002-2005 Aspose Pty Ltd. All Rights Reserved.
//
// This file is part of Aspose.Words. The source code in this file
// is only intended as a supplement to the documentation, and is provided
// "as is", without warranty of any kind, either expressed or implied.
//////////////////////////////////////////////////////////////////////////

import com.aspose.words.Document;
import com.aspose.words.License;
import com.aspose.words.SaveFormat;
import com.aspose.words.demos.*;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.File;
import java.io.IOException;

//Java: In a whole, this class corresponds to C# Aspose.Words.Demos.Viewer.aspx.cs.

public class DemoServlet extends HttpServlet
{
    // Commonly launched only once, when an application server initializes the servlet.
    public void init() throws ServletException
    {
        // Get the path where the resources are (and one extra dir since Demo.init() strips it).
        mWebAppDir = this.getServletContext().getRealPath("/WEB-INF/");

        // *** Licensing: Put the license file into the /WEB-INF folder,
        // otherwise Aspose.Words will work in evaluation mode.
        loadLicense();
    }

    // Called from the web-app index page (because i choose POST method for input form).
    protected void doPost(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException
    {
        // Get the demo selected by the user.
        String demoName = request.getParameter("demo");

        // Get the output format selected by user.
        String formatType = request.getParameter("format");

        // Java-changed: if null, do default demo (in C# - do nothing).
        if (demoName == null)
            demoName = "DinnerInvitation";

        // Create and execute the demo, it produces a document in memory.
        Demo demo = createDemo(demoName);

        // This is needed so the demo knows the path to the database and to the template documents.
        demo.init(mWebAppDir);

        // Java-added rethrow in order to avoid changing this method's signature.
        try
        {
            Document doc = demo.execute();

            // Once we have a document, we can save it to a file, stream or send to the client browser.
            // We just send the document to the browser in this case.
            boolean openNewWindow = request.getParameter("openNewWindow") != null;
            sendToBrowser(doc, demoName, formatType, openNewWindow, response);
            response.flushBuffer();
        }
        catch (Exception e)
        {
            throw new RuntimeException(e);
        }
    }

    private void loadLicense()
    {
        File licenseFile = new File(mWebAppDir + "\\Aspose.Words.Java.lic");
        if (licenseFile.exists())
        {
            // This shows how to license Aspose.Words.
            // If you don't specify a license, Aspose.Words will work in evaluation mode.
            License license = new License();

            // Java-added rethrow in order to avoid changing this method's signature.
            try
            {
                license.setLicense(licenseFile.getAbsolutePath());
            }
            catch (Exception e)
            {
                throw new RuntimeException(e);
            }
        }
    }


    /**
     * Creates and returns an object that can run the demo selected by the user.
     */
    private Demo createDemo(String demoName)
    {
        //java-changed since java switch don't support strings
        if ("DinnerInvitation".equals(demoName))
            return new DinnerInvitationDemo();
        else if ("MailingLabels".equals(demoName))
            return new MailingLabelsDemo();
        else if ("SalesInvoice".equals(demoName))
            return new SalesInvoiceDemo();
        else if ("DocumentBuilder".equals(demoName))
            return new DocumentBuilderDemo();
        else if ("AlternatingRows".equals(demoName))
            return new AlternatingRowsDemo();
        else
            throw new RuntimeException("Unknown demo selected: " + demoName);
    }

    /**
     * Sends the document to the client browser.
     */
    private void sendToBrowser(Document doc, String demoName, String formatType, boolean openNewWindow, HttpServletResponse response)
            throws Exception
    {
        String fileName = demoName + "." + formatType;

        //Add Response header
        if(openNewWindow)
            response.setHeader("content-disposition","attachment; filename=" + fileName);
        else
            response.addHeader("content-disposition","inline; filename=" + fileName);

        if("PDF".equals(formatType))
        {
            //Set Response content type
            response.setContentType("application/pdf");

            Doc2PdfConverter d2p = new Doc2PdfConverter(response.getOutputStream());
            doc.accept(d2p);
        }
        else
        {
            //Set Response content type
            response.setContentType("application/msword");

            //Finally save generated document to Response Out.
            doc.save(response.getOutputStream(), SaveFormat.FORMAT_DOCUMENT);
        }
    }

    private String mWebAppDir;
}

