//////////////////////////////////////////////////////////////////////////
// Copyright 2002-2006 Aspose Pty Ltd. All Rights Reserved.
//
// This file is part of Aspose.Words. The source code in this file
// is only intended as a supplement to the documentation, and is provided
// "as is", without warranty of any kind, either expressed or implied.
//////////////////////////////////////////////////////////////////////////
package com.aspose.words.demos;

import com.aspose.words.Document;
import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.ResultSet;
import java.sql.Statement;

/// <summary>
/// Base class for Aspose.Words.Demos classes that execute specific demos.
/// </summary>
public abstract class Demo
{
    /// <summary>
    /// Call this before calling Execute. We need application path so we can find the database and template documents.
    /// </summary>
    public void init(String appPath)
    {
        String basePath = appPath.substring(0, appPath.lastIndexOf('\\') + 1); 
        mDocPath = basePath + "Documents\\";
        mDatabasePath = basePath + "Database\\";
        mConnString = "jdbc:odbc:DRIVER={Microsoft Access Driver (*.mdb)};" +
            "DBQ=" + mDatabasePath + "Northwind.mdb" + ";UID=Admin";
    }

    void done() throws Exception
    {
        if (mConn != null)
        {
            mConn.close();
            mConn = null;
        }
    }

    /// <summary>
    /// Executes the demo and returns a generated document. Implement in the derived classes.
    /// </summary>
    public abstract Document execute() throws Exception;

    /// <summary>
    /// Utility function that creates a connection, command,
    /// executes the command and return the result in a DataTable.
    /// </summary>
    protected ResultSet executeDataTable(String commandText) throws Exception
    {
		//Load a DB driver that is used by the demos
		Class.forName("sun.jdbc.odbc.JdbcOdbcDriver");
		//DSN-less DB connection.
		Connection mConn = DriverManager.getConnection(getConnString());

		Statement statement = mConn.createStatement(ResultSet.TYPE_SCROLL_INSENSITIVE, ResultSet.CONCUR_UPDATABLE);
		ResultSet result = statement.executeQuery(commandText);
		return result;
    }

    /// <summary>
    /// Gets the folder where the template documents used by the demos are stored.
    /// </summary>
    String getDocPath()
    {
        return mDocPath;
    }

    /// <summary>
    /// Gets the folder where the database used by the demos is stored.
    /// </summary>
    String getDatabasePath()
    {
        return mDatabasePath;
    }

    /// <summary>
    /// Ges the database connection string.
    /// </summary>
    String getConnString()
    {
        return mConnString;
    }

    private String mDocPath;
    private String mDatabasePath;
    private String mConnString;
    private Connection mConn;
}
